@@ -871,7 +871,7 @@ def applyTrapFilter(waves, rise, top, tau, percentage = 0.8, mean = 0, shift = 0
 		numbatches = int(numwaves / batchsize)
 		#set up the main computations
 		if useGPU == True and __gpuAvailable == True: #only try it when it's available and requested
-			results = gpu.gpuTrapFilterImplementation(waves, rise, top, tau, percentage, pretrigger = pretrigger, shift = shift, hdf5ChunkSize = hdf5ChunkSize)
+			results = gpu.gpuTrapCuspFilterImplementation(waves, method='trap', rise=rise, top=top, tau=tau, percentage=percentage, pretrigger = pretrigger, shift = shift, mean = mean, batchsize = batchsize)
 			return np.array(results.real), np.array(results.imag)
 		else: #in this case just use the CPU
 			#first define the filter itself
@@ -961,8 +961,8 @@ def applyCuspFilter(waves, rise, top, tau, percentage = 0.8, mean = 0, shift = 0
 		numbatches = int(numwaves / batchsize)
 		#set up the main computations
 		if useGPU == True and __gpuAvailable == True: #only try it when it's available and requested
-			print('GPU Functionality not enabled for Cusp Filter Yet')
-			return [], []
+			results = gpu.gpuTrapCuspFilterImplementation(waves, method='cusp', rise=rise, top=top, tau=tau, percentage=percentage, pretrigger = pretrigger, shift = shift, mean = mean, batchsize = batchsize)
+			return np.array(results.real), np.array(results.imag)
 		else: #in this case just use the CPU
 			#first define the filter itself
 			filtLen = rise * 2 + top
@@ -1243,9 +1243,6 @@ def pseudoInverseFit(waves, templates, baselines, filtert0 = None, searchRange =
 				waves = da.from_array(waves, chunks = {0: batchsize, 1:-1}) #then put back into dask for chunked operations
 			elif isinstance(waves, np.ndarray):
 				waves = da.from_array(waves, chunks = {0: batchsize, 1:-1})
-		#this applies the trapezoidal filter to the waveforms and grabs the energy and timing results
-		eners = []
-		times = []
 		#do the bulk wave preparation
 		if batchsize == -1:
 			batchsize = len(waves)
